"""
This is a boilerplate pipeline 'sajid_test_file'
generated using Kedro 0.18.3
"""

from kedro.pipeline import Pipeline, node, pipeline


def create_pipeline(**kwargs) -> Pipeline:
    return pipeline([])



"""
This is a boilerplate test file for pipeline 'sajid_test_file'
generated using Kedro 0.18.3.
Please add your pipeline tests here.

Kedro recommends using `pytest` framework, more info about it can be found
in the official documentation:
https://docs.pytest.org/en/latest/getting-started.html
"""



# -*- coding: utf-8 -*-
from setuptools import setup, find_packages

setup(
    name="sajid_test_file",
    version="0.1",
    description="Micro-package `sajid_test_file`",
    packages=find_packages(),
    include_package_data=True,
    install_requires=[],
)
